@@ -112,3 +112,20 @@ def page_dict(request_query, errors):
             elif page_key == 'size':
                 return_dict['size'] = int(value)
     return return_dict
+
+
+def subquery(query, relationship):
+    """Updates query when recursing down relationships."""
+
+    return_query = {}
+    for key, value in query.items():
+        if key == 'fields':
+            return_query['fields'] = value
+        elif key in ('includes', 'filters'):
+            if value and relationship in value:
+                return_query[key] = value[relationship]
+            else:
+                return_query[key] = {}
+        elif key in ('sort', 'page'):
+            return_query[key] = value
+    return return_query
