@@ -127,8 +127,10 @@ class Collection(Resource):
 
         if query_has_parameter(request_query, 'include'):
             if allow:
-                query['includes'] = self.includes_dict(
-                    request_query['include'].split(','), errors, [])
+                query['includes'] = {}
+                self.includes_dict(query['includes'],
+                                   request_query['include'].split(','), errors,
+                                   [])
             else:
                 errors.append(QueryParameterUnsupportedError('include'))
         else:
@@ -156,9 +158,8 @@ class Collection(Resource):
         else:
             query['sort'] = None
 
-    def includes_dict(self, include_parameters, errors, path):
+    def includes_dict(self, include_dict, include_parameters, errors, path):
         """Helper function for parsing request query include parameters."""
-        return_dict = {}
         for include_parameter in include_parameters:
             include, *sub_includes = include_parameter.split('.', 1)
             path.append(include)
@@ -167,11 +168,10 @@ class Collection(Resource):
             except AttributeError:
                 errors.append(IncludeInvalidPathError('.'.join(path)))
             else:
-                return_dict.setdefault(relationship, {}).update(
-                    relationship.rtable.collection.includes_dict(
-                        sub_includes, errors, path))
+                sub_include_dict = include_dict.setdefault(relationship, {})
+                relationship.rtable.collection.includes_dict(
+                    sub_include_dict, sub_includes, errors, path)
             path.pop()
-        return return_dict
 
     def filters_list(self, request_query, errors):
         """Helper function for parsing request query filter parameters."""
